<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
French
</name>

<description>
   <am>French Language Meta-Package</am>
   <ar>French Language Meta-Package</ar>
   <bg>French Language Meta-Package</bg>
   <ca>Meta-paquet de llengua Francesa</ca>
   <cs>French Language Meta-Package</cs>
   <da>Fransk sprog-metapakke</da>
   <de>Französisches Sprach-Meta-Paket</de>
   <el>Γαλλική γλώσσα</el>
   <en>French Language Meta-Package</en>
   <es>French Language Meta-Package</es>
   <et>French Language Meta-Package</et>
   <eu>French Language Meta-Package</eu>
   <fa>French Language Meta-Package</fa>
   <fi>French Language Meta-Package</fi>
   <fr>Méta-paquet pour langue française</fr>
   <he_IL>French Language Meta-Package</he_IL>
   <hi>French Language Meta-Package</hi>
   <hr>French Language Meta-Package</hr>
   <hu>French Language Meta-Package</hu>
   <id>French Language Meta-Package</id>
   <is>French Language Meta-Package</is>
   <it>Meta-pacchetto della lingua francese</it>
   <ja_JP>French Language Meta-Package</ja_JP>
   <ja>French Language Meta-Package</ja>
   <kk>French Language Meta-Package</kk>
   <ko>French Language Meta-Package</ko>
   <lt>French Language Meta-Package</lt>
   <mk>French Language Meta-Package</mk>
   <nb>French Language Meta-Package</nb>
   <nl>Franse Taal Meta-Pakket</nl>
   <pl>Francuski metapakiet językowy</pl>
   <pt_BR>Francês Meta-Pacote de Idioma</pt_BR>
   <pt>Francês Meta-Pacote de Idioma</pt>
   <ro>French Language Meta-Package</ro>
   <ru>French Language Meta-Package</ru>
   <sk>French Language Meta-Package</sk>
   <sl>French Language Meta-Package</sl>
   <sq>French Language Meta-Package</sq>
   <sr>French Language Meta-Package</sr>
   <sv>Franskt Språk Meta-Paket</sv>
   <tr>French Language Meta-Package</tr>
   <uk>French Language Meta-Package</uk>
   <zh_CN>French Language Meta-Package</zh_CN>
   <zh_TW>French Language Meta-Package</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
aspell-fr
myspell-fr
manpages-fr
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
aspell-fr
myspell-fr
manpages-fr
</uninstall_package_names>
</app>
